@@ -380,7 +380,7 @@ gint jack_open(AFormat fmt, gint sample_rate, gint num_channels)
       TRACE("output.channels is %d, jack_open called with %d channels\n", output.channels, input.channels);
       TRACE("output.frequency is %ld, jack_open called with %ld\n", output.frequency, input.frequency);
       TRACE("output.format is %d, jack_open called with %d\n", output.format, input.format);
-      jack_close();
+      JACK_Close(driver);
     } else
     {
         TRACE("output_opened is TRUE and no options changed, not reopening\n");
@@ -592,10 +592,10 @@ void jack_get_volume(int *l, int *r)
 void jack_about(void)
 {
 	dialog = gtk_dialog_new();
-	gtk_window_set_title(GTK_WINDOW(dialog), ("About jack Driver 0.15"));
+	gtk_window_set_title(GTK_WINDOW(dialog), ("About jack Driver 0.16"));
 	gtk_container_border_width(GTK_CONTAINER(dialog), 5);
 	label = gtk_label_new((
-		"XMMS jack Driver 0.15\n\n "
+		"XMMS jack Driver 0.16\n\n "
 		"xmms-jack.sf.net\n"
 		"Chris Morgan<cmorgan@alum.wpi.edu>\n"));
 
